@@ -1,7 +1,7 @@
 pub const BOOTLOADER_HELLO_EVENT_CODE: u16 = 0x0000;
 
 pub const PROGRAMMER_HELLO_EVENT_CODE: u16 = 0x0001;
-pub const PROGRAMMER_START_UPLOAD_EVENT_CODE: u16 = 0x0002;
+pub const PROGRAMMER_START_FIRMWARE_UPGRADE_EVENT_CODE: u16 = 0x0002;
 
 pub const ACK_EVENT_CODE: u16 = 0x0003;
 pub const DATA_EVENT_CODE: u16 = 0x0004;
@@ -15,4 +15,4 @@ pub const BUTTON_RELEASED_EVENT_CODE: u16 = 0x0008;
 
 pub const INTERNAL_SYSTEM_TICK_EVENT_CODE: u16 = 0x0009;
 
-pub const PROGRAMMER_START_CONFIG_UPLOAD_EVENT_CODE: u16 = 0x000a;
+pub const PROGRAMMER_START_CONFIG_UPGRADE_EVENT_CODE: u16 = 0x000a;
